#readelf: -A
#name: C6X PID attribute, -mpid=far
#as: -mpid=far
#source: dummy.s

Attribute Section: c6xabi
File Attributes
  Tag_ISA: C674x
  Tag_ABI_PID: Data addressing position-independent, GOT far from DP
